Page 100 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 100

Home

    system, communication and transportation under control
    of the state, instruments of production owned by the
    state, forced labor, population control, and free education
    in public schools. These are all socialist measures
    leading to total government. According to Marx, only
    after socialism had been established would the all

    powerful state melt away and Communism come into
    being. Needless to say, no all powerful state has ever
    voluntarily given up its military and police power.

    The term "Socialism" is defined by The American

    Heritage Dictionary as, "A social system in which the
    producers possess both political power and the means of
    producing and distributing goods." This, of course,
    describes an economic dictatorship controlled by

    by

    The

    The term "Capitalism" is also misused and
    misunderstood. Capital is defined by The American
    Heritage Dictionary as, "Any form of material wealth
    used or available for use in the production of more
    wealth." Some of the basic forms of capital are money,

    is

    also

    misused

    and

    term

    tools, and natural resources. All are capitalistic.

    The basic conflict concerning capitalism is not the use
    of capital, but who controls the capital. Socialism is a
    capitalistic system controlled by government.
    Competitive free-enterprise is a capitalistic system
    controlled by individuals, without government

    by individuals
    . Monopolistic

    95

    Building Modern Babylon

    economic

    controlled

    government.

    tools, and natural resources. All systems use money,

    government

    interference.

    capitalism is privately